@@ -25,13 +25,6 @@ def subset(client):
         if gtest_case and cls:
             case = gtest_case.group(1)
             client.test_path(make_test_path(cls, case))
-        
-        # handle ctest -N output
-        # Test #1: FooTest.Bar -> (FooTest, Bar)
-        ctest_result = re.match(r'^  Test #\d+: ([^ ]+)$', label)
-        if ctest_result:
-            (cls, case) = ctest_result.group(1).split('.')
-            client.test_path(make_test_path(cls, case))
 
     client.formatter = lambda x: x[0]['name'] + "." + x[1]['name']
     client.run()
